#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Process AWS SSO JSON file to get human-readable data."""

from ..helpers import helper_aws_sso
from ..helpers import helper_common
from ..helpers import helper_aws_entrypoint
from ..helpers.helper_parameters import *
from multithreader import threads

# Enter AWS environment.
session = helper_aws_entrypoint.auth()
sso_admin = session.client(
    'sso-admin',
    region_name=region
)
identity_store = session.client(
    'identitystore',
    region_name=region
)

# List all Permission Sets in the organization.
permission_sets = helper_aws_sso.get_all_permission_set_arns(
    sso_admin,
    sso_instance_arn
)

# Read JSON file.
data = helper_common.read_json(sso_json_input_file)
details = [item['details'] for item in data]

# Read Permission Sets and principals from dictionary.
permission_set_names = helper_aws_sso.read_permission_sets(details)
users = helper_aws_sso.read_users(details)
groups = helper_aws_sso.read_groups(details)

# Execute tasks with multithreading.
items = {
    'identity_store': identity_store,
    'identity_store_id': identity_store_id,
    'sso_admin': sso_admin,
    'sso_instance_arn': sso_instance_arn,
    'permission_sets': permission_sets
}
user_ids = threads(
    helper_aws_sso.get_user_id,
    users,
    items
)
group_ids = threads(
    helper_aws_sso.get_group_id,
    groups,
    items
)
permission_set_arns = threads(
    helper_aws_sso.get_permission_set_arn,
    permission_set_names,
    items
)

# Process JSON file.
processed = helper_aws_sso.process_json(
    sso_json_input_file,
    user_ids,
    group_ids,
    permission_set_arns
)

# Write results to file.
helper_common.write_json_str(
    sso_json_output_file,
    processed
)



#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Collect AWS Security Group details from multiple accounts."""

from ..helpers import helper_aws_ec2
from ..helpers import helper_common
from ..helpers import helper_aws_entrypoint
from ..helpers.helper_parameters import *
from multithreader import threads

# Enter AWS environment.
session = helper_aws_entrypoint.auth()
account_ids = helper_aws_entrypoint.crawler(session)

# Execute task with multithreading.
items = {
    'session': session,
    'assumed_role_name': assumed_role_name,
    'external_id': external_id,
    'region': region
}
results = threads(
    helper_aws_ec2.get_sgs,
    account_ids,
    items
)

# Convert results to CSV data and write to file.
csv_data = helper_common.dicts_to_csv(results)
helper_common.export_csv(csv_data, sgs_get_output_file)



#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Assign AWS SSO Permission Sets to multiple accounts."""

from ..helpers import helper_aws_sso
from ..helpers import helper_common
from ..helpers import helper_aws_entrypoint
from ..helpers.helper_parameters import *
from multithreader import threads
from pprint import pprint as pp

# Enter AWS environment.
session = helper_aws_entrypoint.auth()
sso_admin = session.client(
    'sso-admin',
    region_name=region
)

# Create accounts list from JSON file.
data = helper_common.read_json(sso_assign_input_file)
account_ids = [account['account_id'] for account in data]

# Execute task with multithreading.
items = {
    'sso_admin': sso_admin,
    'sso_instance_arn': sso_instance_arn,
    'data': data
}
results = threads(
    helper_aws_sso.assign_permission_sets_dry_run,
    account_ids,
    items
) if DRY_RUN else threads(
    helper_aws_sso.assign_permission_sets,
    account_ids,
    items
)

# Print results.
pp(results)



#!/usr/bin/env python3
# -*- coding: latin-1 -*-

"""
Run AWS administrative scripts.

Available scripts can be found in the
'scripts' directory of this package.

Prerequisite steps:
1. Copy the parameters/parameters.ini file to your current working directory.
2. Update the file with the necessary values.

Example usage:
from aws_administrator.scripts import aws_sso_get
"""


__version__ = '2.0.1'
__author__ = 'Ahmad Ferdaus Abd Razak'
__status__ = 'Production'



#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Collect AWS SSO Permission Set assignment data from multiple accounts."""

from ..helpers import helper_aws_sso
from ..helpers import helper_common
from ..helpers import helper_aws_entrypoint
from ..helpers.helper_parameters import *
from multithreader import threads

# Enter AWS environment.
session = helper_aws_entrypoint.auth()
account_ids = helper_aws_entrypoint.crawler(session)
sso_admin = session.client(
    'sso-admin',
    region_name=region
)
identity_store = session.client(
    'identitystore',
    region_name=region
)

# Execute task with multithreading.
items = {
    'sso_admin': sso_admin,
    'identity_store': identity_store,
    'sso_instance_arn': sso_instance_arn,
    'identity_store_id': identity_store_id
}
results = threads(
    helper_aws_sso.get_permission_sets,
    account_ids,
    items
)

# Write results to file.
helper_common.write_json_dict(
    sso_get_output_file,
    results
)



#!/usr/bin/env python3
# -*- coding: latin-1 -*-
"""Update AWS SSO User and Group names from mappings files."""

from ..helpers import helper_aws_sso
from ..helpers import helper_common
from ..helpers import helper_aws_entrypoint
from ..helpers.helper_parameters import *
from multithreader import threads
from pprint import pprint as pp

# Enter AWS environment.
session = helper_aws_entrypoint.auth()
identity_store = session.client(
    'identitystore',
    region_name=region
)

# Prepare items for multithreading.
items = {
    'identity_store': identity_store,
    'identity_store_id': identity_store_id,
    'DRY_RUN': DRY_RUN
}

# Read User CSV file and execute updates with multithreading.
if (
    sso_update_user_map_file and
    sso_update_old_user_heading and
    sso_update_new_user_heading
):
    user_data = helper_common.read_csv(sso_update_user_map_file)
    user_dicts = [
        {
            'old_user_name': row[sso_update_old_user_heading],
            'new_user_name': row[sso_update_new_user_heading]
        } for row in user_data
    ]
    user_updates = threads(
        helper_aws_sso.update_user_name,
        user_dicts,
        items
    )
    pp(user_updates)

# Read Group CSV file and execute updates with multithreading.
if (
    sso_update_group_map_file and
    sso_update_old_group_heading and
    sso_update_new_group_heading
):
    group_data = helper_common.read_csv(sso_update_group_map_file)
    group_dicts = [
        {
            'old_group_name': row[sso_update_old_group_heading],
            'new_group_name': row[sso_update_new_group_heading]
        } for row in group_data
    ]
    group_updates = threads(
        helper_aws_sso.update_group_name,
        group_dicts,
        items
    )
    pp(group_updates)
